#!/usr/bin/env python

import argparse
parser = argparse.ArgumentParser(description="Complex distribution for incremental Vietoris-Rips")
parser.add_argument('-f', dest='f', default='pts50.csv', help='filename for input data')
parser.add_argument('-m', dest='m', default=1, type=float, help='maximum eps')
parser.add_argument('-d', dest='d', default=2, type=int, help='maximum dim')
parser.add_argument('-ply', dest='ply', action='store_true', help='file is an ASCII PLY file.')
parser.add_argument('-o', dest='o', default=None, help='filename for output')
args = parser.parse_args()

import scipy
import ik_gpx as ik
import sys
if args.ply:
    pts = ik.read_ply(args.f)
else:
    pts = scipy.loadtxt(args.f)

(edge,fedge,Gnb) = ik.nbhd_graph_edges(pts,args.m)
GV = range(len(pts))
k = args.d

cplx = ik.incremental_order(GV, Gnb, k, fedge, edge)

if args.o:
    fh = open(args.o, 'w')
else:
    fh = sys.stdout

fh.write('fvalue newsize accsize\n')
accsize = 0
currentsize = 0
currentfv = 0
for s in cplx:
    fv = ik.f(s, fedge)
    if fv > currentfv:
        fh.write('%f %d %d\n' % (currentfv, currentsize, accsize))
        accsize += currentsize
        currentsize = 0
        currentfv = fv
    currentsize += 1

if args.o:
    fh.close()
