#!/usr/bin/env python

import timeit

import argparse
parser = argparse.ArgumentParser(description="Timings for in-order incremental Vietoris-Rips")
parser.add_argument('-f', dest='f', default='pts50.csv', help='filename for input data')
parser.add_argument('-m', dest='m', default=1, type=float, help='maximum eps')
parser.add_argument('-d', dest='d', default=2, type=int, help='maximum dim')
parser.add_argument('-i', dest='i', default=1, type=int, help='iterations for repeat timing')
parser.add_argument('-r', dest='r', default=1, type=int, help='iterations for minimum timing')
parser.add_argument('-ply', dest='ply', action='store_true', help='file is an ASCII PLY file.')
parser.add_argument('-o', dest='o', default=None, help='filename for output')
args = parser.parse_args()

#pts = scipy.loadtxt('%s')
#pts = ik.read_ply(ik.chairfile)
#pts = scipy.loadtxt('pts50.csv')
#pts = scipy.loadtxt('pts100.csv')
#pts=[[1.58625115,0.11766562],[0.3155787,0.47123227],[-0.98986756,1.12974255],[0.15760137,0.14993913],[0.31361494,0.08552431]]

loadopts = {
    'scipy': 'pts = scipy.loadtxt("%s")',
    'ply': 'pts = ik.read_ply("%s")',
    }

if args.ply:
    loadkey = 'ply'
else:
    loadkey = 'scipy'
    
setup = '''
import scipy
import ik_gpx as ik
%s
(edge,fedge,Gnb) = ik.nbhd_graph_edges(pts,%f)
GV = range(len(pts))
k = %d
''' % (loadopts[loadkey] % args.f, args.m, args.d)

timer1 = timeit.Timer('ik.incremental(GV, Gnb, k, fedge)', setup=setup)
timer2 = timeit.Timer('ik.incremental_order(GV, Gnb, k, fedge, edge)', setup=setup)

time1 = min(timer1.repeat(repeat=args.r, number=args.i))
time2 = min(timer2.repeat(repeat=args.r, number=args.i))

if args.o:
    f = open(args.o, 'a')
    f.write('%s %f %d %d %d %f %f\n' % (args.f,args.m,args.d,args.r,args.i,time1,time2))
    f.close()
else:
    print "classical:\t", time1
    print "in-order:\t", time2
