from matplotlib import use
use('AGG')
from matplotlib.pyplot import *

from scipy import loadtxt, linspace, logical_and, arange, log
from scipy.stats import linregress

### Timing tests
# scatter plots in-order vs. classical
# separate plots for 100, 200 and 500 points
# square aspect ratio, square plot layout
figure(figsize=(4,4))

ranges = {
    100: [-0.01,0.4,-0.01,0.4],
    200: [-0.15,6,-0.15,6],
    500: [-5,200,-5,200]
    }
ticks = {
    100: arange(0,0.4,0.1),    
    200: arange(0,6),    
    500: arange(0,200,25)
    }
    
for t in [100,200,500]:
    tf = 'timing/tests%d.txt' % t
    tim = loadtxt(tf, usecols=(2,5,6))
    clf()

    plot(tim[tim[:,0]==3,1],tim[tim[:,0]==3,2],'bo',label='3D',mec='none')
    plot(tim[tim[:,0]==4,1],tim[tim[:,0]==4,2],'g+',label='4D')
    plot(tim[tim[:,0]==5,1],tim[tim[:,0]==5,2],'rs',label='5D',mec='none')
    plot([0,1000],[0,1000])
    title('Timings for %d points (seconds)' % t)
    axis(ranges[t])
    xticks(ticks[t])
    yticks(ticks[t])
    ax = gca()
    ax.spines['left'].set_position('zero')
    ax.spines['right'].set_color('none')
    ax.spines['bottom'].set_position('zero')
    ax.spines['top'].set_color('none')
    ax.xaxis.set_ticks_position('bottom')
    ax.yaxis.set_ticks_position('left')
    legend(loc=2)
    savefig('pts%d.pdf' % t,bbox_inches='tight')

### complex complexity: fvalue vs. #simplices
# plot fvalue vs. total simplices. Maybe do a semilog here?


#for t in [100,200,500]:
for t in [100,200,500]:
    clf()

    for j in range(10):
        tf = 'distr/2ddistr%d_%d.txt' % (t,j+1)
        tim = loadtxt(tf,skiprows=1)
        plot(tim[:,0],tim[:,2])
        print t, j, linregress(log(tim[:,0]-tim[0,0]+1),tim[:,2]-tim[0,2])
    semilogy()
    xticks([0.0,0.1,0.2,0.3],[0.0,0.1,0.2,0.3])
    title('Complex growth for %d points' % t)
    savefig('totgrowth%d.pdf' % t,bbox_inches='tight')

    clf()
    binedges = linspace(0,0.3,20)
    bins = [tim[logical_and(binedges[i]<tim[:,0], tim[:,0]<binedges[i+1]),1] for i in range(len(binedges)-1)]
    boxplot(bins,showmeans=True,manage_xticks=False,meanprops={'marker':'x','mec':'r'})
    xlabel('Binning into 20 equal length bins')
    xticks([],[])
    title('Distribution of marginal growth')
    savefig('marginal_equal%d.pdf' % t, bbox_inches='tight')

    clf()
    step = tim.shape[0]/20 + 1
    bins = [tim[j*step:(j+1)*step,1] for j in range(20)]
    widths = [tim[min(tim.shape[0]-1,(j+1)*step),0]-tim[j*step,0] for j in range(20)]
    positions = [0.5*(tim[min(tim.shape[0]-1,(j+1)*step),0]+tim[j*step,0]) for j in range(20)]
    boxplot(bins,showmeans=True,manage_xticks=False,meanprops={'marker':'x','mec':'r'},widths=widths,positions=positions)
    lox,hix,loy,hiy = axis()
    axis([-.01,0.31,loy-5,hiy])
    lox,hix,loy,hiy = axis()
    for x in tim[range(0,tim.shape[0],step),0]:
        plot([x,x],[loy,hiy],'k-',alpha=0.3)
    xlabel('Binning into 20 equal #simplices bins')
    xticks([],[])
    title('Distribution of marginal growth')
    savefig('marginal_size%d.pdf' % t, bbox_inches='tight')
    
